#!/bin/bash


# Copyright (C) 2018-2021 Intel Corporation
# SPDX-License-Identifier: Apache-2.0

sudo pip3 uninstall intel-tensorflow==2.9.1 -y
echo -e "\e[1;32mThe tensorflow is uninstalled\e[0m "


